@@ -1,12 +1,21 @@
 __author__ = "Steffen Andersland"
-__version__ = "0.1.9"
+__version__ = "0.1.10"
 __license__ = "MIT"
-__email__ = "stefandersland@gmial.com"
+__email__ = "steffen@andersland.dev"
 
 import sys
 
 from chromie.parser import parse_args
-from chromie.commands import do_init, do_pack, do_preview
+from chromie.commands import (
+    do_init,
+    do_pack,
+    do_preview,
+    do_preview,
+    do_config,
+    do_upload,
+    do_update,
+    do_publish,
+)
 
 
 def main(argv=None):
@@ -21,6 +30,18 @@ def main(argv=None):
     elif args.command == "preview":
         do_preview(args)
 
+    elif args.command == "config":
+        do_config(args)
+
+    elif args.command == "upload":
+        do_upload(args)
+
+    elif args.command == "update":
+        do_update(args)
+
+    elif args.command == "publish":
+        do_publish(args)
+
     else:
         raise SystemExit("No command selected, for help enter: chromie --help")
 
