@@ -32,6 +32,10 @@ class ChromiePathFinder(dict):
             raise ValueError(f"No path with the name {name} exists")
         return os.path.abspath(os.path.join(self.root, dir))
 
+    def exists(self, name=""):
+        path = os.path.abspath(os.path.join(self.root, name))
+        return os.path.exists(path)
+
 
 class ManifestFile:
     def __init__(self, path, data):
@@ -69,10 +73,12 @@ class ManifestFile:
 
         self.data["version"] = current_version.replace(current_version, new_version)
 
-        return self.write()
+        self.write()
+        return new_version
 
     def set_version(self, version):
         current_version = self.data["version"]
 
         self.data["version"] = current_version.replace(current_version, version)
-        return self.write()
+        self.write()
+        return version
